==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property networkId
 * @property networkName
 * @property repInterval
 */
public data class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs(
    public val networkId: Output<Int>,
    public val networkName: Output<String>,
    public val repInterval: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs> {
    override fun toJava():
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs.builder()
            .networkId(networkId.applyValue({ args0 -> args0 }))
            .networkName(networkName.applyValue({ args0 -> args0 }))
            .repInterval(repInterval?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgsBuilder
internal constructor() {
    private var networkId: Output<Int>? = null

    private var networkName: Output<String>? = null

    private var repInterval: Output<Int>? = null

    /**
     * @param value
     */
    @JvmName("errxkxtahyixpykm")
    public suspend fun networkId(`value`: Output<Int>) {
        this.networkId = value
    }

    /**
     * @param value
     */
    @JvmName("hxophbknkafusrhw")
    public suspend fun networkName(`value`: Output<String>) {
        this.networkName = value
    }

    /**
     * @param value
     */
    @JvmName("lrxwkuuqctkfgyog")
    public suspend fun repInterval(`value`: Output<Int>) {
        this.repInterval = value
    }

    /**
     * @param value
     */
    @JvmName("kiowifgdgpiwjkpg")
    public suspend fun networkId(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkId = mapped
    }

    /**
     * @param value
     */
    @JvmName("oryvakwsfpgmnnxa")
    public suspend fun networkName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkName = mapped
    }

    /**
     * @param value
     */
    @JvmName("udgrsuvknnyiyref")
    public suspend fun repInterval(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.repInterval = mapped
    }

    internal fun build():
        ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs =
        ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs(
            networkId = networkId ?: throw PulumiNullFieldException("networkId"),
            networkName = networkName ?: throw PulumiNullFieldException("networkName"),
            repInterval = repInterval,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/medialive/kotlin/inputs/ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.medialive.kotlin.inputs

import com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property networkId
 * @property networkName
 * @property repInterval
 */
public data class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs(
    public val networkId: Output<Int>,
    public val networkName: Output<String>,
    public val repInterval: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs> {
    override fun toJava(): com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs =
        com.pulumi.aws.medialive.inputs.ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs.builder()
            .networkId(networkId.applyValue({ args0 -> args0 }))
            .networkName(networkName.applyValue({ args0 -> args0 }))
            .repInterval(repInterval?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs].
 */
@PulumiTagMarker
public class
ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgsBuilder
internal constructor() {
    private var networkId: Output<Int>? = null

    private var networkName: Output<String>? = null

    private var repInterval: Output<Int>? = null

    /**
     * @param value
     */
    @JvmName("aghsvebjcfyrxkck")
    public suspend fun networkId(`value`: Output<Int>) {
        this.networkId = value
    }

    /**
     * @param value
     */
    @JvmName("nwuguiccuxtlugpi")
    public suspend fun networkName(`value`: Output<String>) {
        this.networkName = value
    }

    /**
     * @param value
     */
    @JvmName("rxexvjexsjekpqyq")
    public suspend fun repInterval(`value`: Output<Int>) {
        this.repInterval = value
    }

    /**
     * @param value
     */
    @JvmName("cclnvfifryjtjvmk")
    public suspend fun networkId(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkId = mapped
    }

    /**
     * @param value
     */
    @JvmName("lllwfbmopootfuoa")
    public suspend fun networkName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkName = mapped
    }

    /**
     * @param value
     */
    @JvmName("wsqjasixyfbvtbuo")
    public suspend fun repInterval(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.repInterval = mapped
    }

    internal fun build(): ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs =
        ChannelEncoderSettingsOutputGroupOutputOutputSettingsUdpOutputSettingsContainerSettingsM2tsSettingsDvbNitSettingsArgs(
            networkId = networkId ?: throw PulumiNullFieldException("networkId"),
            networkName = networkName ?: throw PulumiNullFieldException("networkName"),
            repInterval = repInterval,
        )
}
